@@ -18,7 +18,6 @@ class GerritClient(object):
 
     """
 
-    GERRIT_AUTH_SUFFIX = "/a"
     default_headers = {"Content-Type": "application/json; charset=UTF-8"}
 
     def __init__(
@@ -31,6 +30,7 @@ class GerritClient(object):
         cert=None,
         timeout=60,
         max_retries=None,
+        auth_suffix="/a"
     ):
         if not password and not use_netrc:
             raise ValueError(
@@ -43,6 +43,7 @@ class GerritClient(object):
             password = self.get_password_from_netrc_file()
 
         self.requester = Requester(
+            base_url=base_url,
             username=username,
             password=password,
             ssl_verify=ssl_verify,
@@ -50,6 +51,7 @@ class GerritClient(object):
             timeout=timeout,
             max_retries=max_retries,
         )
+        self.auth_suffix = auth_suffix
 
     def get_password_from_netrc_file(self):
         """
@@ -60,9 +62,7 @@ class GerritClient(object):
         netrc_client = netrc.netrc()
         auth_tokens = netrc_client.authenticators(self._base_url)
         if not auth_tokens:
-            raise ValueError(
-                "The '{}' host name is not found in netrc file.".format(self._base_url)
-            )
+            raise ValueError(f"The '{self._base_url}' host name is not found in netrc file.")
         return auth_tokens[2]
 
     @classmethod
@@ -82,7 +82,7 @@ class GerritClient(object):
         :param endpoint: service endpoint as str
         :return: complete url (including host and port) as str
         """
-        return "{}{}{}".format(self._base_url, self.GERRIT_AUTH_SUFFIX, endpoint)
+        return f"{self._base_url}{self.auth_suffix}{endpoint}"
 
     @staticmethod
     def decode_response(response):
@@ -109,7 +109,7 @@ class GerritClient(object):
         try:
             return json.loads(content)
         except ValueError:
-            raise ValueError("Invalid json content: {}".format(content))
+            raise ValueError(f"Invalid json content: {content}")
 
     @property
     def config(self):
