@@ -7,6 +7,7 @@ from gerrit.changes.change import GerritChange
 class GerritChanges(object):
     def __init__(self, gerrit):
         self.gerrit = gerrit
+        self.endpoint = "/changes"
 
     def search(self, query, options=None, limit=None, skip=None):
         """
@@ -14,7 +15,7 @@ class GerritChanges(object):
 
         .. code-block:: python
 
-            query = ["is:open+owner:self", "is:open+reviewer:self+-owner:self", "is:closed+owner:self+limit:5"]
+            query = "is:open+owner:self+is:mergeable"
             result = client.changes.search(query=query, options=["LABELS"])
 
         :param query: Queries as a list of string
@@ -31,15 +32,7 @@ class GerritChanges(object):
             if v is not None
         }
 
-        endpoint = "/changes/{query}".format(
-            query="?q={query}".format(query="&q=".join(query))
-        )
-
-        response = self.gerrit.requester.get(
-            self.gerrit.get_endpoint_url(endpoint), params
-        )
-        result = self.gerrit.decode_response(response)
-        return result
+        return self.gerrit.get(self.endpoint + f"/?q={query}", params=params)
 
     def get(self, id_, detailed=False, options=None):
         """
@@ -52,16 +45,13 @@ class GerritChanges(object):
         :param options: List of options to fetch additional data about a change
         :return:
         """
-        endpoint = "/changes/{id_}/{detail}".format(
-            id_=id_, detail="detail" if detailed else ""
-        )
-        params = {"o": options}
 
-        response = self.gerrit.requester.get(
-            self.gerrit.get_endpoint_url(endpoint), params
-        )
-        result = self.gerrit.decode_response(response)
-        return GerritChange.parse(result, gerrit=self.gerrit)
+        endpoint = self.endpoint + f"/{id_}/"
+        if detailed:
+            endpoint += "detail"
+
+        result = self.gerrit.get(endpoint, params={"o": options})
+        return GerritChange(json=result, gerrit=self.gerrit)
 
     def create(self, input_):
         """
@@ -82,13 +72,8 @@ class GerritChanges(object):
           https://gerrit-review.googlesource.com/Documentation/rest-api-changes.html#change-input
         :return:
         """
-        endpoint = "/changes/"
-        base_url = self.gerrit.get_endpoint_url(endpoint)
-        response = self.gerrit.requester.post(
-            base_url, json=input_, headers=self.gerrit.default_headers
-        )
-        result = self.gerrit.decode_response(response)
-        return GerritChange.parse(result, gerrit=self.gerrit)
+        result = self.gerrit.post(self.endpoint + '/', json=input_, headers=self.gerrit.default_headers)
+        return GerritChange(json=result, gerrit=self.gerrit)
 
     def delete(self, id_):
         """
@@ -97,5 +82,4 @@ class GerritChanges(object):
         :param id_: change id
         :return:
         """
-        endpoint = "/changes/%s" % id_
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
+        self.gerrit.delete(self.endpoint + f"/{id_}")
