@@ -7,6 +7,7 @@ class GerritGroupMembers(object):
     def __init__(self, group_id, gerrit):
         self.group_id = group_id
         self.gerrit = gerrit
+        self.endpoint = f"/groups/{self.group_id}/members"
 
     def list(self):
         """
@@ -16,9 +17,7 @@ class GerritGroupMembers(object):
 
         :return:
         """
-        endpoint = "/groups/%s/members/" % self.group_id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint)
 
         accounts = []
         for item in result:
@@ -36,9 +35,7 @@ class GerritGroupMembers(object):
         :param username: account username
         :return:
         """
-        endpoint = "/groups/%s/members/%s" % (self.group_id, username)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + f"/{username}")
         if result:
             username = result.get("username")
             return self.gerrit.accounts.get(username)
@@ -52,9 +49,7 @@ class GerritGroupMembers(object):
         :param username: account username
         :return:
         """
-        endpoint = "/groups/%s/members/%s" % (self.group_id, username)
-        response = self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.put(self.endpoint + f"/{username}")
         if result:
             username = result.get("username")
             return self.gerrit.accounts.get(username)
@@ -68,5 +63,4 @@ class GerritGroupMembers(object):
         :param username: account username
         :return:
         """
-        endpoint = "/groups/%s/members/%s" % (self.group_id, username)
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
\ No newline at end of file
+        self.gerrit.delete(self.endpoint + f"/{username}")
