@@ -7,6 +7,7 @@ class GerritGroupSubGroups(object):
     def __init__(self, group_id, gerrit):
         self.group_id = group_id
         self.gerrit = gerrit
+        self.endpoint = f"/groups/{self.group_id}/groups/"
 
     def list(self):
         """
@@ -16,9 +17,7 @@ class GerritGroupSubGroups(object):
 
         :return:
         """
-        endpoint = "/groups/%s/groups/" % self.group_id
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint)
         subgroups = []
         for item in result:
             group_id = item.get("id")
@@ -35,9 +34,7 @@ class GerritGroupSubGroups(object):
         :param subgroup: subgroup id or name
         :return:
         """
-        endpoint = "/groups/%s/groups/%s" % (self.group_id, subgroup)
-        response = self.gerrit.requester.get(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.get(self.endpoint + f"/{subgroup}")
         if result:
             subgroup_id = result.get("id")
             return self.gerrit.groups.get(subgroup_id)
@@ -51,9 +48,7 @@ class GerritGroupSubGroups(object):
         :param subgroup: subgroup id or name
         :return:
         """
-        endpoint = "/groups/%s/groups/%s" % (self.group_id, subgroup)
-        response = self.gerrit.requester.put(self.gerrit.get_endpoint_url(endpoint))
-        result = self.gerrit.decode_response(response)
+        result = self.gerrit.put(self.endpoint + f"/{subgroup}")
         if result:
             subgroup_id = result.get("id")
             return self.gerrit.groups.get(subgroup_id)
@@ -67,5 +62,4 @@ class GerritGroupSubGroups(object):
         :param subgroup: subgroup id or name
         :return:
         """
-        endpoint = "/groups/%s/groups/%s" % (self.group_id, subgroup)
-        self.gerrit.requester.delete(self.gerrit.get_endpoint_url(endpoint))
\ No newline at end of file
+        self.gerrit.delete(self.endpoint + f"/{subgroup}")
