@@ -18,20 +18,18 @@ class Entity(object):
 
         for item in self.required:
             if item not in kwargs.keys():
+                name = self.__class__.__name__
                 logger.warning(
-                    "*** Warning! {} missing a required keyword argument '{}' ***".format(
-                        self.__class__.__name__, item
-                    )
+                    f"*** Warning! {name} missing a required keyword argument '{item}' ***"
                 )
 
         for (k, v) in kwargs.items():
             if k in self.attributes:
                 setattr(self, k, v)
             else:
+                name = self.__class__.__name__
                 logger.warning(
-                    "*** Warning! {} got an unexpected keyword argument: '{}' ***".format(
-                        self.__class__.__name__, k
-                    )
+                    f"*** Warning! {name} got an unexpected keyword argument: '{k}' ***"
                 )
 
     def __getattr__(self, key):
